Documentation
¶
Index ¶
Constants ¶
const ( // RDONLY maps the memory read-only. // Attempts to write to the MemObject object will result in undefined behavior. RDONLY = 0 // RDWR maps the memory as read-write. Writes to the MemObject object will update the // underlying file. RDWR = 1 << iota // COPY maps the memory as copy-on-write. Writes to the MemObject object will affect // memory, but the underlying file will remain unchanged. COPY // EXEC If EXEC is set, the mapped memory is marked as executable. EXEC )
const ( // ANON If the ANON flag is set, the mapped memory will not be backed by a file. ANON = 1 << iota )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Object ¶
type Object []byte
Object represents a file mapped into memory.
func OpenMapper ¶
OpenMapper maps an entire file into memory.
If ANON is set in flags, f is ignored.
func (*Object) Lock ¶
Lock keeps the mapped region in physical memory, ensuring that it will not be swapped out.
func (*Object) Unlock ¶
Unlock reverses the effect of Lock, allowing the mapped region to potentially be swapped out. If m is already unlocked, aan error will result.
func (*Object) Unmap ¶
Unmap deletes the memory mapped region, flushes any remaining changes, and sets m to nil. Trying to read or write any remaining references to m after Unmap is called will result in undefined behavior. Unmap should only be called on the slice value that was originally returned from a call to FileMap. Calling Unmap on a derived slice may cause errors.